@@ -1,6 +1,7 @@
 #include <pwd.h>
 #include <errno.h>
 #include <stdio.h>
+#include <string.h>
 #include <unistd.h>
 #include <locale.h>
 #include <pthread.h>
@@ -8,10 +9,13 @@
 #include <sys/types.h>
 #ifdef __linux__
 #include <sys/sysinfo.h>
+#else
+#include <sys/sysctl.h>
 #endif
 #include <sys/utsname.h>
 #include <notcurses/direct.h>
 #include <notcurses/notcurses.h>
+#include "ncart.h"
 
 typedef struct distro_info {
   const char* name;            // must match 'lsb_release -i'
@@ -33,6 +37,8 @@ typedef struct fetched_info {
   int dimy, dimx;              // extracted from xrandr
   char* cpu_model;             // FIXME don't handle hetero setups yet
   int core_count;
+  // if there is no other logo found, fall back to a logo filched from neofetch
+  const char* neologo;         // text with color substitution templates
 } fetched_info;
 
 static void
@@ -69,6 +75,28 @@ static distro_info distros[] = {
   },
 };
 
+static int
+fetch_bsd_cpuinfo(fetched_info* fi){
+#ifdef __linux__
+  (void)fi;
+#else
+  size_t len = sizeof(fi->core_count);
+  int mib[2] = { CTL_HW, HW_NCPU };
+  if(sysctl(mib, sizeof(mib) / sizeof(*mib), &fi->core_count, &len, NULL, 0)){
+    fprintf(stderr, "Coudln't acquire CTL_HW+HW_NCPU sysctl (%s)\n", strerror(errno));
+    return -1;
+  }
+  mib[1] = HW_MODEL;
+  size_t modellen = 80; // FIXME?
+  fi->cpu_model = malloc(modellen);
+  if(sysctl(mib, sizeof(mib) / sizeof(*mib), fi->cpu_model, &modellen, NULL, 0)){
+    fprintf(stderr, "Coudln't acquire CTL_HW+HW_MODEL sysctl (%s)\n", strerror(errno));
+    return -1;
+  }
+#endif
+  return 0;
+}
+
 static int
 fetch_cpu_info(fetched_info* fi){
   FILE* cpuinfo = fopen("/proc/cpuinfo", "re");
@@ -78,16 +106,37 @@ fetch_cpu_info(fetched_info* fi){
   }
   char buf[BUFSIZ];
   while(fgets(buf, sizeof(buf), cpuinfo)){
-#define TAG "model name\t:"
+#define CORE "core id"
+// model name doesn't appear on all architectures, so fall back to vendor_id
+#define TAG "model name"
+#define VEND "vendor_id"
     if(strncmp(buf, TAG, strlen(TAG)) == 0){
-      if(fi->cpu_model == NULL){
-        char* nl = strchr(buf + strlen(TAG), '\n');
+      // model name trumps vendor_id
+      free(fi->cpu_model);
+      char* start = strchr(buf + strlen(TAG), ':');
+      if(start){
+        ++start;
+        char* nl = strchr(start, '\n');
         *nl = '\0';
-        fi->cpu_model = strdup(buf + strlen(TAG));
+        fi->cpu_model = strdup(start);
       }
+    }else if(strncmp(buf, VEND, strlen(VEND)) == 0){
+      // vendor_id ought only be used in the absence of model name
+      if(fi->cpu_model == NULL){
+        char* start = strchr(buf + strlen(VEND), ':');
+        if(start){
+          ++start;
+          char* nl = strchr(start, '\n');
+          *nl = '\0';
+          fi->cpu_model = strdup(start);
+        }
+      }
+    }else if(strncmp(buf, CORE, strlen(CORE)) == 0){
       ++fi->core_count;
     }
+#undef VEND
 #undef TAG
+#undef CORE
   }
   return 0;
 }
@@ -206,6 +255,9 @@ linux_ncneofetch(fetched_info* fi){
     }
   }
   if(dinfo->name == NULL){
+    if(fi->logo == NULL){
+      fi->neologo = get_neofetch_art(distro);
+    }
     dinfo = NULL;
   }
   free(distro);
@@ -243,6 +295,7 @@ unix_gethostname(fetched_info* fi){
 typedef enum {
   NCNEO_LINUX,
   NCNEO_FREEBSD,
+  NCNEO_DRAGONFLY,
   NCNEO_UNKNOWN,
 } ncneo_kernel_e;
 
@@ -259,6 +312,8 @@ get_kernel(fetched_info* fi){
     return NCNEO_LINUX;
   }else if(strcmp(uts.sysname, "FreeBSD") == 0){
     return NCNEO_FREEBSD;
+  }else if(strcmp(uts.sysname, "DragonFly") == 0){
+    return NCNEO_DRAGONFLY;
   }
   fprintf(stderr, "Unknown operating system via uname: %s\n", uts.sysname);
   return NCNEO_UNKNOWN;
@@ -270,6 +325,18 @@ freebsd_ncneofetch(fetched_info* fi){
     .name = "FreeBSD",
     .logofile = NULL, // FIXME
   };
+  fi->neologo = get_neofetch_art("BSD"); // use big daemon logo
+  fi->distro_pretty = NULL;
+  return &fbsd;
+}
+
+static const distro_info*
+dragonfly_ncneofetch(fetched_info* fi){
+  static distro_info fbsd = {
+    .name = "DragonFly BSD",
+    .logofile = NULL, // FIXME
+  };
+  fi->neologo = get_neofetch_art("dragonfly");
   fi->distro_pretty = NULL;
   return &fbsd;
 }
@@ -343,7 +410,7 @@ place_infoplane(struct ncdirect* ncd, int planeheight){
 
 static int
 infoplane_notcurses(struct notcurses* nc, const fetched_info* fi, int planeheight){
-  const int planewidth = 60;
+  const int planewidth = 72;
   int dimy;
   struct ncplane* std = notcurses_stddim_yx(nc, &dimy, NULL);
   struct ncplane_options nopts = {
@@ -450,9 +517,49 @@ infoplane(struct ncdirect* ncd, const fetched_info* fi){
 struct marshal {
   struct ncdirect* nc;
   const distro_info* dinfo;
-  const char* logo; // read from /etc/os-release, may be NULL
+  const char* logo; // read from /etc/os-release (or builtin), may be NULL
+  const char* neologo; // fallback from neofetch, text with color sub templates
 };
 
+// present a neofetch-style logo. we want to substitute colors for ${cN} inline
+// sequences, and center the logo.
+static int
+neologo_present(struct ncdirect* nc, const char* nlogo){
+  // find the maximum line length in columns by iterating over the logo
+  size_t maxlinelen = 0;
+  size_t linelen; // length in bytes, including newline
+  char** lines = NULL;
+  int linecount = 0;
+  for(const char* cur = nlogo ; *cur ; cur += linelen){
+    const char* nl = strchr(cur, '\n');
+    if(nl){
+      linelen = (nl + 1) - cur;
+    }else{
+      linelen = strlen(cur);
+    }
+    char** tmpl;
+    if((tmpl = realloc(lines, sizeof(*lines) * (linecount + 1))) == NULL){
+      free(lines);
+      return -1;
+    }
+    lines = tmpl;
+    lines[linecount++] = strndup(cur, linelen);
+    size_t collen = ncstrwidth(lines[linecount - 1]);
+    if(collen > maxlinelen){
+      maxlinelen = collen;
+    }
+  }
+  const int leftpad = (80 - maxlinelen) / 2;
+  for(int i = 0 ; i < linecount ; ++i){
+    printf("%*.*s%s", leftpad, leftpad, "", lines[i]);
+    free(lines[i]);
+  }
+  free(lines);
+  ncdirect_set_fg_rgb(nc, 0xba55d3);
+  ncdirect_printf_aligned(nc, -1, NCALIGN_CENTER, "(no image file is known for your distro)");
+  return 0;
+}
+
 static void*
 display_thread(void* vmarshal){
   struct marshal* m = vmarshal;
@@ -462,12 +569,14 @@ display_thread(void* vmarshal){
                              NCBLIT_DEFAULT, NCSCALE_SCALE_HIRES)){
       return NULL;
     }
-  }else if(m->dinfo){
-    if(m->dinfo->logofile){
-      if(ncdirect_render_image(m->nc, m->dinfo->logofile, NCALIGN_CENTER,
-                               NCBLIT_DEFAULT, NCSCALE_SCALE_HIRES)){
-        return NULL;
-      }
+  }else if(m->dinfo && m->dinfo->logofile){
+    if(ncdirect_render_image(m->nc, m->dinfo->logofile, NCALIGN_CENTER,
+                             NCBLIT_DEFAULT, NCSCALE_SCALE_HIRES)){
+      return NULL;
+    }
+  }else if(m->neologo){
+    if(neologo_present(m->nc, m->neologo)){
+      return NULL;
     }
   }
   return NULL;
@@ -484,6 +593,9 @@ ncneofetch(struct ncdirect* nc){
     case NCNEO_FREEBSD:
       fi.distro = freebsd_ncneofetch(&fi);
       break;
+    case NCNEO_DRAGONFLY:
+      fi.distro = dragonfly_ncneofetch(&fi);
+      break;
     case NCNEO_UNKNOWN:
       break;
   }
@@ -493,6 +605,7 @@ ncneofetch(struct ncdirect* nc){
     .nc = nc,
     .dinfo = fi.distro,
     .logo = fi.logo,
+    .neologo = fi.neologo,
   };
   pthread_t tid;
   const bool launched = !pthread_create(&tid, NULL, display_thread, &display_marshal);
@@ -500,7 +613,11 @@ ncneofetch(struct ncdirect* nc){
   unix_getusername(&fi);
   fetch_env_vars(&fi);
   fetch_x_props(&fi);
-  fetch_cpu_info(&fi);
+  if(kern == NCNEO_LINUX){
+    fetch_cpu_info(&fi);
+  }else{
+    fetch_bsd_cpuinfo(&fi);
+  }
   if(launched){
     pthread_join(tid, NULL);
   }
