@@ -8,19 +8,6 @@ extern "C" {
 #include "version.h"
 #include "builddef.h"
 
-#ifdef USE_FFMPEG
-#include <libavutil/error.h>
-#include <libavutil/frame.h>
-#include <libavutil/pixdesc.h>
-#include <libavutil/version.h>
-#include <libswscale/version.h>
-#include <libavformat/version.h>
-#else
-#ifdef USE_OIIO
-const char* oiio_version(void);
-#endif
-#endif
-
 #include <term.h>
 #include <time.h>
 #include <stdio.h>
@@ -42,6 +29,7 @@ const char* oiio_version(void);
 #include "egcpool.h"
 
 struct esctrie;
+struct ncvisual_details;
 
 // we can't define multipart ncvisual here, because OIIO requires C++ syntax,
 // and we can't go throwing C++ syntax into this header. so it goes.
@@ -681,9 +669,13 @@ memdup(const void* src, size_t len){
 
 void* bgra_to_rgba(const void* data, int rows, int rowstride, int cols);
 
-int rgba_blit_dispatch(ncplane* nc, const struct blitset* bset, int placey,
-                       int placex, int linesize, const void* data, int begy,
-                       int begx, int leny, int lenx, bool blendcolors);
+static inline int
+rgba_blit_dispatch(ncplane* nc, const struct blitset* bset, int placey,
+                   int placex, int linesize, const void* data, int begy,
+                   int begx, int leny, int lenx, bool blendcolors){
+  return bset->blit(nc, placey, placex, linesize, data, begy, begx,
+                    leny, lenx, blendcolors);
+}
 
 // find the "center" cell of two lengths. in the case of even rows/columns, we
 // place the center on the top/left. in such a case there will be one more
@@ -860,9 +852,6 @@ int get_controlling_tty(void);
     nclog("%s:%d:" fmt, __func__, __LINE__, ##__VA_ARGS__); } \
   } }while(0);
 
-// Convert a notcurses log level to some multimedia library equivalent.
-int ffmpeg_log_level(ncloglevel_e level);
-
 int term_setstyle(FILE* out, unsigned cur, unsigned targ, unsigned stylebit,
                   const char* ton, const char* toff);
 
@@ -1068,6 +1057,32 @@ int setup_signals(void* nc, bool no_quit_sigs, bool no_winch_sig,
                   int(*handler)(void*));
 int drop_signals(void* nc);
 
+void ncvisual_printbanner(const notcurses* nc);
+
+typedef struct ncvisual_implementation {
+  int (*ncvisual_init)(int loglevel);
+  void (*ncvisual_printbanner)(const struct notcurses* nc);
+  int (*ncvisual_blit)(struct ncvisual* ncv, int rows, int cols, ncplane* n,
+                       const struct blitset* bset, int placey, int placex,
+                       int begy, int begx, int leny, int lenx,
+                       bool blendcolors);
+  struct ncvisual* (*ncvisual_create)(void);
+  struct ncvisual* (*ncvisual_from_file)(const char* fname);
+  // ncv constructors other than ncvisual_from_file() need to set up the
+  // AVFrame* 'frame' according to their own data, which is assumed to
+  // have been prepared already in 'ncv'.
+  void (*ncvisual_details_seed)(struct ncvisual* ncv);
+  void (*ncvisual_details_destroy)(struct ncvisual_details* deets);
+  int (*ncvisual_decode)(struct ncvisual* nc);
+  char* (*ncvisual_subtitle)(const struct ncvisual* ncv);
+  bool canopen_images;
+  bool canopen_videos;
+} ncvisual_implementation;
+
+// assigned by libnotcurses.so if linked with multimedia
+extern const ncvisual_implementation* visual_implementation
+  __attribute__ ((visibility("default")));
+
 #ifdef __cplusplus
 }
 #endif
