@@ -754,28 +754,6 @@ void notcurses_stats_reset(notcurses* nc, ncstats* stats){
   stash_stats(nc);
 }
 
-// Convert a notcurses log level to some multimedia library equivalent.
-int ffmpeg_log_level(ncloglevel_e level){
-#ifdef USE_FFMPEG
-  switch(level){
-    case NCLOGLEVEL_SILENT: return AV_LOG_QUIET;
-    case NCLOGLEVEL_PANIC: return AV_LOG_PANIC;
-    case NCLOGLEVEL_FATAL: return AV_LOG_FATAL;
-    case NCLOGLEVEL_ERROR: return AV_LOG_ERROR;
-    case NCLOGLEVEL_WARNING: return AV_LOG_WARNING;
-    case NCLOGLEVEL_INFO: return AV_LOG_INFO;
-    case NCLOGLEVEL_VERBOSE: return AV_LOG_VERBOSE;
-    case NCLOGLEVEL_DEBUG: return AV_LOG_DEBUG;
-    case NCLOGLEVEL_TRACE: return AV_LOG_TRACE;
-    default: break;
-  }
-  fprintf(stderr, "Invalid log level: %d\n", level);
-  return AV_LOG_TRACE;
-#else
-  return level;
-#endif
-}
-
 // unless the suppress_banner flag was set, print some version information and
 // (if applicable) warnings to stdout. we are not yet on the alternate screen.
 static void
@@ -802,19 +780,7 @@ init_banner(const notcurses* nc){
 #error "No __BYTE_ORDER__ definition"
 #endif
            , curses_version());
-#ifdef USE_FFMPEG
-    printf("  avformat %u.%u.%u avutil %u.%u.%u swscale %u.%u.%u\n",
-          LIBAVFORMAT_VERSION_MAJOR, LIBAVFORMAT_VERSION_MINOR, LIBAVFORMAT_VERSION_MICRO,
-          LIBAVUTIL_VERSION_MAJOR, LIBAVUTIL_VERSION_MINOR, LIBAVUTIL_VERSION_MICRO,
-          LIBSWSCALE_VERSION_MAJOR, LIBSWSCALE_VERSION_MINOR, LIBSWSCALE_VERSION_MICRO);
-#else
-#ifdef USE_OIIO
-    printf("  openimageio %s\n", oiio_version());
-#else
-    term_fg_palindex(nc, stderr, nc->tcache.colors <= 88 ? 1 % nc->tcache.colors : 0xcb);
-    fprintf(stderr, "\n Warning! Notcurses was built without multimedia support.\n");
-#endif
-#endif
+    ncvisual_printbanner(nc);
     fflush(stdout);
     term_fg_palindex(nc, stderr, nc->tcache.colors <= 88 ? 1 % nc->tcache.colors : 0xcb);
     if(!nc->tcache.RGBflag){ // FIXME
@@ -916,7 +882,8 @@ int ncinputlayer_init(ncinputlayer* nilayer, FILE* infp){
 }
 
 // initialize a recursive mutex lock in a way that works on both glibc + musl
-int recursive_lock_init(pthread_mutex_t *lock){
+static int
+recursive_lock_init(pthread_mutex_t *lock){
 #ifndef __GLIBC__
 #define PTHREAD_MUTEX_RECURSIVE_NP PTHREAD_MUTEX_RECURSIVE
 #endif
@@ -939,7 +906,7 @@ int recursive_lock_init(pthread_mutex_t *lock){
 #endif
 }
 
-notcurses* notcurses_init(const notcurses_options* opts, FILE* outfp){
+notcurses* notcurses_core_init(const notcurses_options* opts, FILE* outfp){
   notcurses_options defaultopts;
   memset(&defaultopts, 0, sizeof(defaultopts));
   if(!opts){
@@ -1057,7 +1024,7 @@ notcurses* notcurses_init(const notcurses_options* opts, FILE* outfp){
     terminfostr(&ret->tcache.smcup, "smcup");
     terminfostr(&ret->tcache.rmcup, "rmcup");
   }
-  if(ncvisual_init(ffmpeg_log_level(ret->loglevel))){
+  if(ncvisual_init(ret->loglevel)){
     goto err;
   }
   ret->stdplane = NULL;
