@@ -4,10 +4,72 @@
 #include "visual-details.h"
 #include "internal.h"
 
+const ncvisual_implementation* visual_implementation = nullptr;
+
+auto ncvisual_decode(ncvisual* nc) -> int {
+  if(!visual_implementation){
+    return -1;
+  }
+  return visual_implementation->ncvisual_decode(nc);
+}
+
+auto ncvisual_blit(ncvisual* ncv, int rows, int cols, ncplane* n,
+                   const struct blitset* bset, int placey, int placex,
+                   int begy, int begx, int leny, int lenx,
+                   bool blendcolors) -> int {
+  int ret = -1;
+  if(visual_implementation){
+    if(visual_implementation->ncvisual_blit(ncv, rows, cols, n, bset, placey, placex,
+                           begy, begx, leny, lenx, blendcolors) >= 0){
+      ret = 0;
+    }
+  }else{
+    if(rgba_blit_dispatch(n, bset, placey, placex, ncv->rowstride, ncv->data,
+                          begy, begx, leny, lenx, blendcolors) >= 0){
+      ret = 0;
+    }
+  }
+  return ret;
+}
+
 // ncv constructors other than ncvisual_from_file() need to set up the
 // AVFrame* 'frame' according to their own data, which is assumed to
 // have been prepared already in 'ncv'.
-auto ncvisual_details_seed(struct ncvisual* ncv) -> void;
+auto ncvisual_details_seed(struct ncvisual* ncv) -> void {
+  if(visual_implementation){
+    visual_implementation->ncvisual_details_seed(ncv);
+  }
+}
+
+auto ncvisual_init(int loglevel) -> int {
+  if(visual_implementation){
+    return visual_implementation->ncvisual_init(loglevel);
+  }
+  return 0;
+}
+
+auto ncvisual_from_file(const char* filename) -> ncvisual* {
+  if(!visual_implementation){
+    return nullptr;
+  }
+  return visual_implementation->ncvisual_from_file(filename);
+}
+
+auto ncvisual_create(void) -> ncvisual* {
+  if(visual_implementation){
+    return visual_implementation->ncvisual_create();
+  }
+  return new ncvisual{};
+}
+
+auto ncvisual_printbanner(const notcurses* nc) -> void {
+  if(visual_implementation){
+    visual_implementation->ncvisual_printbanner(nc);
+  }else{
+    term_fg_palindex(nc, stderr, nc->tcache.colors <= 88 ? 1 % nc->tcache.colors : 0xcb);
+    fprintf(stderr, "\n Warning! Notcurses was built without multimedia support.\n");
+  }
+}
 
 auto ncvisual_geom(const notcurses* nc, const ncvisual* n,
                    const struct ncvisual_options* vopts,
@@ -482,9 +544,15 @@ auto ncvisual_from_plane(const ncplane* n, ncblitter_e blit, int begy, int begx,
   return ncv;
 }
 
+auto ncvisual_details_destroy(ncvisual_details* deets){
+  if(visual_implementation){
+    visual_implementation->ncvisual_details_destroy(deets);
+  }
+}
+
 auto ncvisual_destroy(ncvisual* ncv) -> void {
   if(ncv){
-    ncvisual_details_destroy(&ncv->details);
+    ncvisual_details_destroy(ncv->details);
     if(ncv->owndata){
       free(ncv->data);
     }
@@ -567,24 +635,18 @@ auto ncvisual_polyfill_yx(ncvisual* n, int y, int x, uint32_t rgba) -> int {
   return ncvisual_polyfill_recurse(n, y, x, rgba, *pixel);
 }
 
-#ifndef USE_OIIO // built without ffmpeg or oiio
-#ifndef USE_FFMPEG
-auto ncvisual_from_file(const char* filename) -> ncvisual* {
-  (void)filename;
-  return nullptr;
-}
-
 auto notcurses_canopen_images(const notcurses* nc __attribute__ ((unused))) -> bool {
-  return false;
+  if(!visual_implementation){
+    return false;
+  }
+  return visual_implementation->canopen_images;
 }
 
 auto notcurses_canopen_videos(const notcurses* nc __attribute__ ((unused))) -> bool {
-  return false;
-}
-
-auto ncvisual_decode(ncvisual* nc) -> int {
-  (void)nc;
-  return -1;
+  if(!visual_implementation){
+    return false;
+  }
+  return visual_implementation->canopen_videos;
 }
 
 auto ncvisual_decode_loop(ncvisual* nc) -> int {
@@ -605,30 +667,10 @@ auto ncvisual_stream(notcurses* nc, ncvisual* ncv, float timescale,
 }
 
 auto ncvisual_subtitle(const ncvisual* ncv) -> char* {
-  (void)ncv;
-  return nullptr;
-}
-
-auto ncvisual_init(int loglevel) -> int {
-  (void)loglevel;
-  return 0; // allow success here
-}
-
-auto ncvisual_blit(ncvisual* ncv, int rows, int cols, ncplane* n,
-                   const struct blitset* bset, int placey, int placex,
-                   int begy, int begx, int leny, int lenx,
-                   bool blendcolors) -> int {
-  (void)rows;
-  (void)cols;
-  if(rgba_blit_dispatch(n, bset, placey, placex, ncv->rowstride, ncv->data,
-                        begy, begx, leny, lenx, blendcolors) < 0){
-    return -1;
+  if(!visual_implementation){
+    return nullptr;
   }
-  return 0;
-}
-
-auto ncvisual_details_seed(struct ncvisual* ncv) -> void {
-  (void)ncv;
+  return visual_implementation->ncvisual_subtitle(ncv);
 }
 
 auto ncvisual_resize(ncvisual* nc, int rows, int cols) -> int {
@@ -640,6 +682,3 @@ auto ncvisual_resize(ncvisual* nc, int rows, int cols) -> int {
   }
   return -1;
 }
-
-#endif
-#endif
